@@ -6,6 +6,7 @@
 #include <dirent.h>
 #include <string.h>
 #include <ctype.h>
+#include <math.h>
 #include <libgnomeprint/gnome-font.h>
 #include <gnome-xml/tree.h>
 #include <gnome-xml/parser.h>
@@ -845,31 +846,11 @@ gnome_font_load_afm (GnomeFontMap *fontmap_entry)
 	    debugmsg ("%d %d %d\n",
 		     ktab[i].glyph1, ktab[i].glyph2, ktab[i].x_amt);
 #endif
-
-	  /* Free the Font_Info structure */
-	  for (i = 0; i < fi->numOfPairs; i++)
-	    {
-	      free (fi->pkd[i].name1);
-	      free (fi->pkd[i].name2);
-	    }
-	  free (fi->pkd);
-	  for (i = 0; i < fi->numOfChars; i++)
-	    {
-	      Ligature *ligs, *next;
-
-	      for (ligs = fi->cmi[i].ligs; ligs != NULL; ligs = next)
-		{
-		  next = ligs->next;
-		  free (ligs->succ);
-		  free (ligs->lig);
-		  free (ligs);
-		}
-	      free (fi->cmi[i].name);
-	    }
-	  free (fi->cmi);
-	  free (fi);
 	}
 
+      if (fi)
+	parseFileFree (fi);
+
       fclose (afm_f);
     }
 }
@@ -2056,7 +2037,7 @@ static GnomeDisplayFont *create_display_font (const char *family,
 	  return NULL;
 
   gfus = closest->fontmap_entry;
-  gnome_font = gnome_font_new_closest (family, weight, italic, points * scale);
+  gnome_font = gnome_font_new_closest (family, weight, italic, ceil(points * scale));
   wpdf = (GnomeDisplayFont *) g_malloc (sizeof (GnomeDisplayFont));
 
   wpdf->unsized_font = gfus;
@@ -2100,7 +2081,7 @@ GnomeDisplayFont *gnome_get_display_font (const char *family,
 	      family,
 	      gnome_font_weight_to_string (weight),
 	      italic?"t":"f",
-	      (int) (points * scale));
+	      (int) ceil(points * scale));
 
   if (! scaled_display_fonts) initialize_hashes ();
 
@@ -2124,6 +2105,17 @@ GnomeDisplayFont *gnome_get_display_font (const char *family,
   return wpdf;
 }
 
+int
+gnome_display_font_height (GnomeDisplayFont *gdf)
+{
+	g_return_val_if_fail (gdf != NULL, 0);
+	g_return_val_if_fail (gdf->gdk_font != NULL, 0);
+	g_return_val_if_fail (gdf->gnome_font != NULL, 0);
+
+	return MAX (gdf->gdk_font->ascent + gdf->gdk_font->descent,
+		    gdf->gnome_font->size);
+}
+
 GnomeDisplayFont *gnome_font_get_display_font( GnomeFont *font )
 {
   return gnome_get_display_font( font->fontmap_entry->familyname,
