@@ -41,6 +41,7 @@ typedef struct {
 	double      *dash_values;
 	double       dash_offset;
 	GnomeCanvasBpathDef *bpath;
+	GnomeCanvasGroup    *group;
 
 	GnomeFont    *font;
 
@@ -48,6 +49,7 @@ typedef struct {
 	double       page_affine [6];
 	double       base_affine [6];
 	double       startup_page_affine [6];
+
 } GraphicContext;
 
 struct _GnomePrintPreviewPrivate {
@@ -148,10 +150,10 @@ dump_gc (GnomePrintPreview *pp)
 		g->affine [4],
 		g->affine [5]);
 
-	if (g->bpath){
+	if (g->bpath) {
 		int i;
 		
-		for (i = 0; i < g->bpath->n_bpath; i++){
+		for (i = 0; i < g->bpath->n_bpath; i++) {
 
 		}
 	}
@@ -167,7 +169,7 @@ dump_gc (GnomePrintPreview *pp)
 static void
 lazy_showpage_check (GnomePrintPreviewPrivate *priv)
 {
-	if (priv->auto_hide_page_on_stroke){
+	if (priv->auto_hide_page_on_stroke) {
 		gnome_canvas_item_hide (priv->auto_hide_page_on_stroke);
 		priv->auto_hide_page_on_stroke = NULL;
 	}
@@ -216,6 +218,7 @@ gpp_moveto (GnomePrintContext *pc, double x, double y)
 
 	map (priv, &x, &y);
 	gnome_canvas_bpath_def_moveto (gc (priv)->bpath, x, y);
+
 	return 1;
 }
 
@@ -248,6 +251,7 @@ gpp_curveto (GnomePrintContext *pc,
 	map (priv, &x2, &y2);
 	map (priv, &x3, &y3);
 	gnome_canvas_bpath_def_curveto (gc (priv)->bpath, x1, y1, x2, y2, x3, y3);
+
 	return 1;
 }
 
@@ -271,6 +275,7 @@ gpp_setrgbcolor (GnomePrintContext *pc, double r, double g, double b)
 	GnomePrintPreviewPrivate *priv = pp->priv;
 
 	set_color (&gc (priv)->color, r, g, b, - 1);
+
 	return 1;
 }
 
@@ -298,7 +303,7 @@ gpp_stroke (GnomePrintContext *pc)
 	 * Special case: libart does not like stroking of lines
 	 */
 	close = 1;
-	if (g->bpath->n_bpath == 2){
+	if (g->bpath->n_bpath == 2) {
 		if ((g->bpath->bpath [0].code == ART_MOVETO ||
 		     g->bpath->bpath [0].code == ART_MOVETO_OPEN) &&
 		    g->bpath->bpath [1].code == ART_LINETO)
@@ -308,8 +313,7 @@ gpp_stroke (GnomePrintContext *pc)
 	if (close)
 		close_path (g->bpath);
 	lazy_showpage_check (priv);
-	item = gnome_canvas_item_new (
-		GNOME_CANVAS_GROUP (priv->page),
+	item = gnome_canvas_item_new (g->group,
 		gnome_canvas_bpath_get_type (),
 		"bpath",       g->bpath,
 		"width_units", g->width,
@@ -335,7 +339,7 @@ gpp_strokepath (GnomePrintContext *pc)
 	g_warning ("Strokepath is not tested");
 	lazy_showpage_check (priv);
 	item = gnome_canvas_item_new (
-		GNOME_CANVAS_GROUP (priv->page),
+		gc (priv)->group,
 		gnome_canvas_bpath_get_type (),
 		"bpath",       gc (priv)->bpath,
 		"width_units", gc (priv)->width,
@@ -359,7 +363,7 @@ gpp_fill (GnomePrintContext *pc)
 	close_path (gc (priv)->bpath);
 	lazy_showpage_check (priv);
 	item = gnome_canvas_item_new (
-		GNOME_CANVAS_GROUP (priv->page),
+		gc (priv)->group,
 		gnome_canvas_bpath_get_type (),
 		"bpath",       gc (priv)->bpath,
 		"width_units", gc (priv)->width,
@@ -379,6 +383,7 @@ gpp_eofill (GnomePrintContext *pc)
 
 	g_warning ("eofill operator not implemented yet");
 	gc_clear_bpath (gc (priv));
+
 	return 1;
 }
 
@@ -406,7 +411,7 @@ gpp_setlinejoin (GnomePrintContext *pc, int jointype)
 	GnomePrintPreview *pp = GNOME_PRINT_PREVIEW (pc);
 	GnomePrintPreviewPrivate *priv = pp->priv;
 
-	switch (jointype){
+	switch (jointype) {
 	default:
 		gc (priv)->join = GDK_JOIN_MITER;
 		g_warning ("Need to support all linejoin methods");
@@ -420,7 +425,7 @@ gpp_setlinecap (GnomePrintContext *pc, int captype)
 	GnomePrintPreview *pp = GNOME_PRINT_PREVIEW (pc);
 	GnomePrintPreviewPrivate *priv = pp->priv;
 
-	switch (captype){
+	switch (captype) {
 	default:
 		gc (priv)->linecap = GDK_CAP_BUTT;
 		g_warning ("Need to support all linecap methods");
@@ -521,8 +526,14 @@ gpp_gsave (GnomePrintContext *pc)
 
 	if (newctx->font)
 		gtk_object_ref (GTK_OBJECT (newctx->font));
+
+	newctx->group = GNOME_CANVAS_GROUP (gnome_canvas_item_new (
+		ctx->group,
+		gnome_canvas_group_get_type (),
+		NULL));
 	
 	priv->context_list = g_slist_prepend (priv->context_list, newctx);
+/*	g_warning ("ggp_gsave\n");*/
 
 	return 1;
 }
@@ -555,7 +566,12 @@ gpp_grestore (GnomePrintContext *pc)
 static int
 gpp_clip (GnomePrintContext *pc)
 {
-	g_warning ("Implement clip");
+	GnomePrintPreview *pp = GNOME_PRINT_PREVIEW (pc);
+	GnomePrintPreviewPrivate *priv = pp->priv;
+	GraphicContext *g = gc (priv);
+
+	gc_clear_bpath (g);
+/*	g_warning ("Implement clip");*/
 	return 1;
 }
 
@@ -618,7 +634,7 @@ gpp_image (GnomePrintContext *pc, const char *data, int width, int height, int r
 
 	lazy_showpage_check (priv);
 	item = gnome_canvas_item_new (
-		GNOME_CANVAS_GROUP (priv->page),
+		g->group,
 		gnome_canvas_image_get_type (),
 		"pixbuf", pixbuf,
 		"x",      0.0,
@@ -684,6 +700,11 @@ gpp_showpage (GnomePrintContext *pc)
 		"y", 0.0,
 		NULL);
 
+	/*
+	 * Setup base group
+	 */
+	gc (priv)->group = GNOME_CANVAS_GROUP (priv->page);
+
 	/*
 	 * Reset affine and path
 	 */
@@ -733,7 +754,7 @@ gpp_show (GnomePrintContext *pc, char const *text)
 	double transform [6], inverse[6];
 	GraphicContext *g = gc (priv);
 
-
+	
 	if (g->font == NULL){
 		g_warning ("Show invoked without prior setfont");
 		return -1;
@@ -775,7 +796,7 @@ gpp_show (GnomePrintContext *pc, char const *text)
 
 	lazy_showpage_check (priv);
 	item = gnome_canvas_item_new (
-		GNOME_CANVAS_GROUP (priv->page),
+		g->group,
 		gnome_canvas_hacktext_get_type (),
 		"x",           p.x,
 		"y",           p.y,
@@ -822,7 +843,7 @@ gpp_finalize (GtkObject *object)
 	GnomePrintPreview *pp = GNOME_PRINT_PREVIEW (object);
 	GnomePrintPreviewPrivate *priv = pp->priv;
 	GSList *l;
-	int i;
+	int     i;
 
 	for (l = priv->context_list; l; l = l->next)
 		gc_free (l->data);
@@ -836,15 +857,20 @@ gpp_finalize (GtkObject *object)
 		g_hash_table_destroy (priv->font_hash);
 	}
 
+#if 0
 	for (i = 0; i < priv->pages->len; i++){
 		GnomeCanvasItem *page;
 		
 		page = g_array_index (priv->pages, GnomeCanvasItem *, i);
 		gtk_object_destroy (GTK_OBJECT (page));
 	}
+#endif
 
-	gtk_object_destroy (GTK_OBJECT (priv->page));
-	gtk_object_destroy (GTK_OBJECT (priv->root));
+	if (priv->page)
+		gtk_object_destroy (GTK_OBJECT (priv->page));
+
+	if (priv->root)
+		gtk_object_destroy (GTK_OBJECT (priv->root));
 	
 	g_array_free (priv->pages, TRUE);
 
@@ -913,6 +939,12 @@ gpp_init (GnomePrintPreview *preview)
 	priv->pages = g_array_new (FALSE, FALSE, sizeof (GnomeCanvasItem *));
 }
 
+static void
+clear_val (GtkObject *object, void **val)
+{
+	*val = NULL;
+}
+
 /**
  * gnome_print_preview_construct:
  * @preview: the #GnomePrintPreview object to construct
@@ -958,6 +990,15 @@ gnome_print_preview_construct (GnomePrintPreview *preview,
 		"y", 0.0,
 		NULL);
 
+	gtk_signal_connect (GTK_OBJECT (preview->priv->page), "destroy",
+			    GTK_SIGNAL_FUNC (clear_val), &preview->priv->page);
+	gtk_signal_connect (GTK_OBJECT (preview->priv->root), "destroy",
+			    GTK_SIGNAL_FUNC (clear_val), &preview->priv->root);
+	/*
+	 * Setup base group
+	 */
+	gc (preview->priv)->group = GNOME_CANVAS_GROUP (preview->priv->page);
+
 	/*
 	 * Setup the affines
 	 */
