@@ -5,10 +5,11 @@
 #include <libgnomeprint/gnome-printer.h>
 #include <libgnomeprint/gnome-font.h>
 #include <libgnomeprint/gnome-text.h>
+#include <libart_lgpl/art_vpath.h>
+#include <libart_lgpl/art_bpath.h>
 
 #ifdef __cplusplus
 extern "C" {
-#pragma }
 #endif /* __cplusplus */
 
 #include <gtk/gtk.h>
@@ -97,6 +98,8 @@ struct _GnomePrintContextClass
   int (* showpage)         (GnomePrintContext *pc);
 
   int (* close)            (GnomePrintContext *pc);
+
+  int (* setopacity)       (GnomePrintContext *pc, double opacity);
 };
 
 
@@ -190,6 +193,16 @@ gnome_print_textline	     (GnomePrintContext *pc, GnomeTextLine *line);
 int
 gnome_print_showpage         (GnomePrintContext *pc);
 
+int
+gnome_print_setopacity       (GnomePrintContext *pc, double opacity);
+
+void
+gnome_print_vpath            (GnomePrintContext * gpc, ArtVpath * vpath, gboolean append);
+
+void
+gnome_print_bpath            (GnomePrintContext * gpc, ArtBpath * bpath, gboolean append);
+
+
 /* These functions are wrapper functions around capabilities that may
    or may not be deconvolved in back ends. */
 
