@@ -3,8 +3,18 @@
 #include <ctype.h>
 #include <math.h>
 
-#include "libart_lgpl/art_bpath.h"
+#include <glib.h>
 
+#include <libart_lgpl/art_misc.h>
+#include <libart_lgpl/art_rect.h>
+#include <libart_lgpl/art_vpath.h>
+#include <libart_lgpl/art_bpath.h>
+#include <libart_lgpl/art_vpath_bpath.h>
+#include <libart_lgpl/art_vpath_dash.h>
+#include <libart_lgpl/art_svp.h>
+#include <libart_lgpl/art_svp_vpath.h>
+#include <libart_lgpl/art_svp_wind.h>
+#include <libart_lgpl/art_svp_point.h>
 
 #include "gt1-misc.h"
 #include "gt1-region.h"
@@ -2499,8 +2509,8 @@ bs_end (BezState *bs)
 
 static ArtBpath *
 convert_glyph_code_to_begt1_path (Gt1PSContext *psc, Gt1String *glyph_code,
-				Gt1Dict *fontdict,
-				double *p_wx)
+				  Gt1Dict *fontdict,
+				  double *p_wx)
 {
   BezState *bs;
 
@@ -2808,6 +2818,7 @@ struct _Gt1LoadedFont {
   Gt1Dict *fontdict;
   Gt1NameId *encoding;
   Gt1NameId id_charstrings;
+  GHashTable *glyph_outlines;
 };
 
 /* The kern pair table is actually a hash table */
@@ -2891,6 +2902,78 @@ replace_extension (const char *filename, const char *ext)
   return new_fn;
 }
 
+static guint
+glyph_outline_hash (gconstpointer v)
+{
+	const Gt1GlyphOutline *go = v;
+
+	return go->ch;
+}
+
+static gint
+glyph_outline_equal (gconstpointer a, gconstpointer b)
+{
+	const Gt1GlyphOutline *ga = a;
+	const Gt1GlyphOutline *gb = b;
+
+	if (ga->ch == gb->ch)
+		return TRUE;
+	else
+		return FALSE;
+}
+
+/* Find the bounding box of a bezier path. */
+static void
+art_drect_bpath (ArtDRect *bbox, const ArtBpath *bpath)
+{
+	/* This implementation is a hack. The real thing needs to go
+	   into libart. */
+	ArtVpath *vpath;
+
+	vpath = art_bez_path_to_vec (bpath, 0.25);
+	art_vpath_bbox_drect (vpath, bbox);
+	art_free (vpath);
+}
+
+Gt1GlyphOutline *
+gt1_glyph_outline_lookup (Gt1LoadedFont *font, int c)
+{
+	Gt1GlyphOutline o, *go;
+
+	o.ch = c;
+	if ((go = g_hash_table_lookup (font->glyph_outlines, &o)))
+		return go;
+	
+	go = g_new (Gt1GlyphOutline, 1);
+
+	go->ch = c;
+	go->bpath = gt1_get_glyph_outline (font, c, &go->wx);
+	art_drect_bpath (&go->bbox, go->bpath);
+
+	g_hash_table_insert (font->glyph_outlines, go, go);
+
+	return go;
+}
+
+static void
+destroy_outline (gpointer key, gpointer value, gpointer user_data)
+{
+	Gt1GlyphOutline *o = key;
+
+	if (o->bpath)
+		art_free (o->bpath);
+	o->bpath = NULL;
+	g_free (o);
+}
+
+static void
+glyph_outlines_destroy (Gt1LoadedFont *font)
+{
+	if (font->glyph_outlines)
+		g_hash_table_foreach (font->glyph_outlines,
+				      destroy_outline, NULL);
+}
+
 Gt1LoadedFont *
 gt1_load_font (const char *filename)
 {
@@ -2909,9 +2992,65 @@ gt1_load_font (const char *filename)
 
   char *flat;
 
-  Gt1NameId *stdenc;
+  Gt1NameId *encode_table_1,
+            *encode_table_2,
+            *encode_table_3,
+            *encode_table_4,
+            *enc_std,
+            *enc_isolatin,
+            *enc_utf8;
   int i;
 
+  /* Encode table 1 from 040 to 0176, ascii */ 
+  static char *  encode_table_1_names[] = {
+/*4x */"space",      "exclam",     "quotedbl",   "numbersign", "dollar",     "percent",     "ampersand",  "quoteright",
+/*5x */"parenleft",  "parenright", "asterisk",   "plus",       "comma",      "hyphen",      "period",     "slash",
+/*6x */"zero",       "one",        "two",        "three",      "four",       "five",        "six",        "seven",
+/*7x */"eight",      "nine",       "colon",      "semicolon",  "less",       "equal",       "greater",    "question",
+/*10x*/"at",         "A",          "B",          "C",          "D",          "E",           "F",          "G",
+/*11x*/"H",          "I",          "J",          "K",          "L",          "M",           "N",          "O",
+/*12x*/"P",          "Q",          "R",          "S",          "T",          "U",           "V",          "W",
+/*13x*/"X",          "Y",          "Z",          "bracketleft","backslash",  "bracketright","asciicircum","underscore",
+/*14x*/"quoteleft",  "a",          "b",          "c",          "b",          "e",           "f",          "g",
+/*15x*/"h",          "i",          "j",          "k",          "l",          "m",           "n",          "o",
+/*16x*/"p",          "q",          "r",          "s",          "t",          "u",           "v",          "w",
+/*170*/"x",          "y",          "z",          "braceleft",  "bar",        "braceright",  "asciitilde"};
+   
+  /* From 0241 ( 161) to 0320 ( 208 ) */ 
+static char *  encode_table_2_names[] = {
+/*24x*/                 "exclamdown",   "cent",          "sterling",      "fraction",      "yen",             "florin",    "section",
+/*25x*/"currency",      "quotesingle",  "quotedblleft",  "guillemotleft", "guilsinglleft", "guilsinglright",  "fi",        "fl",
+/*26x*/".notdef",       "endash",       "dagger",        "daggerdbl",     "periodcentered",".notdef",         "paragraph", "bullet",
+/*27x*/"quotesinglbase","quotedblbase", "quotedblright", "guillemotright","ellipsis",      "perthousand",     ".notdef",   "questiondown",
+/*30x*/".notdef",       "grave",        "acute",         "circumflex",    "tilde",         "macron",          "breve",     "dotaccent",
+/*31x*/"dieresis",      ".notdef",      "ring",          "cedilla",       ".notdef",       "hungarumlaut",    "ogonek",    "caron",
+/*32x*/"emdash",        "123456789012345678"};
+
+/* Table # 3 : from 0220 ( 144 ) to 0377 ( 255 ) */
+static char *  encode_table_3_names[] = {
+/*22x*/"dotlessi",      "grave",        "acute",         "circumflex",    "tilde",         "macron",          "breve",        "dotaccent",
+/*23x*/"dieresis",      ".notdef",      "ring",          "cedilla",       ".notdef",       "hungarumlaut",    "ogonek",       "caron",
+/*24x*/"space",         "exclamdown",   "cent",          "sterling",      "currency",      "yen",             "brokenbar",    "section",
+/*25x*/"dieresis",      "copyright",    "ordfeminine",   "guillemotleft", "logicalnot",    "hyphen",          "registered",   "macron",
+/*26x*/"degree",        "plusminus",    "twosuperior",   "threesuperior", "acute",         "mu",              "paragraph",    "periodcentered",
+/*27x*/"cedilla",       "onesuperior",  "ordmasculine",  "guillemotright","onequarter",    "onehalf",         "threequarters","questiondown",
+/*30x*/"Agrave",        "Aacute",       "Acircumflex",   "Atilde",        "Adieresis",     "Aring",           "AE",           "Ccedilla",
+/*31x*/"Egrave",        "Eacute",       "Ecircumflex",   "Edieresis",     "Igrave",        "Iacute",          "Icircumflex",  "Idieresis",
+/*32x*/"Eth",           "Ntilde",       "Ograve",        "Oacute",        "Ocircumflex",   "Otilde",          "Odieresis",    "multiply",
+/*33x*/"Oslash",        "Ugrave",       "Uacute",        "Ucircumflex",   "Udieresis",     "Yacute",          "Thorn",        "germandbls",
+/*340*/"agrave",        "aacute",       "acircumflex",   "atilde",        "adieresis",     "aring",           "ae",           "ccedilla",
+/*35x*/"egrave",        "eacute",       "ecircumflex",   "edieresis",     "igrave",        "iacute",          "icircumflex",  "idieresis",
+/*36x*/"eth",           "ntilde",       "ograve",        "oacute",        "ocircumflex",   "otilde",          "odieresis",    "divide",
+/*37x*/"oslash",        "ugrave",       "uacute",        "ucircumflex",   "udieresis",     "yacute",          "thorn",        "ydieresis",
+       "123456789012345678"};
+
+/* Table #4 : from 0341 ( 225 ) to 0373 (251), very scattered tho */
+static char *  encode_table_4_names[] = {
+/*34x*/                 "AE",           ".notdef",      ".notdef",       ".notdef",       ".notdef",       ".notdef",         ".notdef",
+/*35x*/"Lslash",        "Oslash",       "OE",           "ordmasculine",  ".notdef",       ".notdef",       ".notdef",         ".notdef",
+/*36x*/".notdef",       "ae",           ".notdef",      ".notdef",       ".notdef",       "dotlessi",      ".notdef",         ".notdef",
+/*37x*/"lslash",        "oslash",       "oe",           "germandbls",    "123456789012345678"};
+
   f = fopen (filename, "rb");
   if (f == NULL) return NULL;
 
@@ -2932,7 +3071,6 @@ gt1_load_font (const char *filename)
   */
 
   /* this is a good place to do a "magic" computation on the input file. */
-
   if (pfb_size)
     {
       if (((unsigned char *)pfb)[0] == 128)
@@ -2973,6 +3111,8 @@ gt1_load_font (const char *filename)
 
   loaded_font = gt1_new (Gt1LoadedFont, 1);
   loaded_font->psc = psc;
+  loaded_font->glyph_outlines = g_hash_table_new (glyph_outline_hash,
+						  glyph_outline_equal);
   
   fontdict = psc->fonts->entries[0].val.val.dict_val;
   loaded_font->fontdict = fontdict;
@@ -2991,161 +3131,47 @@ gt1_load_font (const char *filename)
     }
   gt1_free (afm_filename);
 
-  stdenc = gt1_new (Gt1NameId, 256);
+  enc_std        = gt1_new (Gt1NameId, 256);
+  enc_isolatin   = gt1_new (Gt1NameId, 256);
+  enc_utf8       = gt1_new (Gt1NameId, 256);
+  encode_table_1 = gt1_new (Gt1NameId, 256);
+  encode_table_2 = gt1_new (Gt1NameId, 256);
+  encode_table_3 = gt1_new (Gt1NameId, 256);
+  encode_table_4 = gt1_new (Gt1NameId, 256);
+
   for (i = 0; i < 256; i++)
-    stdenc[i] = gt1_name_context_intern (psc->nc, ".notdef");
-  stdenc[32] = gt1_name_context_intern (psc->nc, "space");
-  stdenc[33] = gt1_name_context_intern (psc->nc, "exclam");
-  stdenc[34] = gt1_name_context_intern (psc->nc, "quotedbl");
-  stdenc[35] = gt1_name_context_intern (psc->nc, "numbersign");
-  stdenc[36] = gt1_name_context_intern (psc->nc, "dollar");
-  stdenc[37] = gt1_name_context_intern (psc->nc, "percent");
-  stdenc[38] = gt1_name_context_intern (psc->nc, "ampersand");
-  stdenc[39] = gt1_name_context_intern (psc->nc, "quoteright");
-  stdenc[40] = gt1_name_context_intern (psc->nc, "parenleft");
-  stdenc[41] = gt1_name_context_intern (psc->nc, "parenright");
-  stdenc[42] = gt1_name_context_intern (psc->nc, "asterisk");
-  stdenc[43] = gt1_name_context_intern (psc->nc, "plus");
-  stdenc[44] = gt1_name_context_intern (psc->nc, "comma");
-  stdenc[45] = gt1_name_context_intern (psc->nc, "hyphen");
-  stdenc[46] = gt1_name_context_intern (psc->nc, "period");
-  stdenc[47] = gt1_name_context_intern (psc->nc, "slash");
-  stdenc[48] = gt1_name_context_intern (psc->nc, "zero");
-  stdenc[49] = gt1_name_context_intern (psc->nc, "one");
-  stdenc[50] = gt1_name_context_intern (psc->nc, "two");
-  stdenc[51] = gt1_name_context_intern (psc->nc, "three");
-  stdenc[52] = gt1_name_context_intern (psc->nc, "four");
-  stdenc[53] = gt1_name_context_intern (psc->nc, "five");
-  stdenc[54] = gt1_name_context_intern (psc->nc, "six");
-  stdenc[55] = gt1_name_context_intern (psc->nc, "seven");
-  stdenc[56] = gt1_name_context_intern (psc->nc, "eight");
-  stdenc[57] = gt1_name_context_intern (psc->nc, "nine");
-  stdenc[58] = gt1_name_context_intern (psc->nc, "colon");
-  stdenc[59] = gt1_name_context_intern (psc->nc, "semicolon");
-  stdenc[60] = gt1_name_context_intern (psc->nc, "less");
-  stdenc[61] = gt1_name_context_intern (psc->nc, "equal");
-  stdenc[62] = gt1_name_context_intern (psc->nc, "greater");
-  stdenc[63] = gt1_name_context_intern (psc->nc, "question");
-  stdenc[64] = gt1_name_context_intern (psc->nc, "at");
-  stdenc[65] = gt1_name_context_intern (psc->nc, "A");
-  stdenc[66] = gt1_name_context_intern (psc->nc, "B");
-  stdenc[67] = gt1_name_context_intern (psc->nc, "C");
-  stdenc[68] = gt1_name_context_intern (psc->nc, "D");
-  stdenc[69] = gt1_name_context_intern (psc->nc, "E");
-  stdenc[70] = gt1_name_context_intern (psc->nc, "F");
-  stdenc[71] = gt1_name_context_intern (psc->nc, "G");
-  stdenc[72] = gt1_name_context_intern (psc->nc, "H");
-  stdenc[73] = gt1_name_context_intern (psc->nc, "I");
-  stdenc[74] = gt1_name_context_intern (psc->nc, "J");
-  stdenc[75] = gt1_name_context_intern (psc->nc, "K");
-  stdenc[76] = gt1_name_context_intern (psc->nc, "L");
-  stdenc[77] = gt1_name_context_intern (psc->nc, "M");
-  stdenc[78] = gt1_name_context_intern (psc->nc, "N");
-  stdenc[79] = gt1_name_context_intern (psc->nc, "O");
-  stdenc[80] = gt1_name_context_intern (psc->nc, "P");
-  stdenc[81] = gt1_name_context_intern (psc->nc, "Q");
-  stdenc[82] = gt1_name_context_intern (psc->nc, "R");
-  stdenc[83] = gt1_name_context_intern (psc->nc, "S");
-  stdenc[84] = gt1_name_context_intern (psc->nc, "T");
-  stdenc[85] = gt1_name_context_intern (psc->nc, "U");
-  stdenc[86] = gt1_name_context_intern (psc->nc, "V");
-  stdenc[87] = gt1_name_context_intern (psc->nc, "W");
-  stdenc[88] = gt1_name_context_intern (psc->nc, "X");
-  stdenc[89] = gt1_name_context_intern (psc->nc, "Y");
-  stdenc[90] = gt1_name_context_intern (psc->nc, "Z");
-  stdenc[91] = gt1_name_context_intern (psc->nc, "bracketleft");
-  stdenc[92] = gt1_name_context_intern (psc->nc, "backslash");
-  stdenc[93] = gt1_name_context_intern (psc->nc, "bracketright");
-  stdenc[94] = gt1_name_context_intern (psc->nc, "asciicircum");
-  stdenc[95] = gt1_name_context_intern (psc->nc, "underscore");
-  stdenc[96] = gt1_name_context_intern (psc->nc, "quoteleft");
-  stdenc[97] = gt1_name_context_intern (psc->nc, "a");
-  stdenc[98] = gt1_name_context_intern (psc->nc, "b");
-  stdenc[99] = gt1_name_context_intern (psc->nc, "c");
-  stdenc[100] = gt1_name_context_intern (psc->nc, "d");
-  stdenc[101] = gt1_name_context_intern (psc->nc, "e");
-  stdenc[102] = gt1_name_context_intern (psc->nc, "f");
-  stdenc[103] = gt1_name_context_intern (psc->nc, "g");
-  stdenc[104] = gt1_name_context_intern (psc->nc, "h");
-  stdenc[105] = gt1_name_context_intern (psc->nc, "i");
-  stdenc[106] = gt1_name_context_intern (psc->nc, "j");
-  stdenc[107] = gt1_name_context_intern (psc->nc, "k");
-  stdenc[108] = gt1_name_context_intern (psc->nc, "l");
-  stdenc[109] = gt1_name_context_intern (psc->nc, "m");
-  stdenc[110] = gt1_name_context_intern (psc->nc, "n");
-  stdenc[111] = gt1_name_context_intern (psc->nc, "o");
-  stdenc[112] = gt1_name_context_intern (psc->nc, "p");
-  stdenc[113] = gt1_name_context_intern (psc->nc, "q");
-  stdenc[114] = gt1_name_context_intern (psc->nc, "r");
-  stdenc[115] = gt1_name_context_intern (psc->nc, "s");
-  stdenc[116] = gt1_name_context_intern (psc->nc, "t");
-  stdenc[117] = gt1_name_context_intern (psc->nc, "u");
-  stdenc[118] = gt1_name_context_intern (psc->nc, "v");
-  stdenc[119] = gt1_name_context_intern (psc->nc, "w");
-  stdenc[120] = gt1_name_context_intern (psc->nc, "x");
-  stdenc[121] = gt1_name_context_intern (psc->nc, "y");
-  stdenc[122] = gt1_name_context_intern (psc->nc, "z");
-  stdenc[123] = gt1_name_context_intern (psc->nc, "braceleft");
-  stdenc[124] = gt1_name_context_intern (psc->nc, "bar");
-  stdenc[125] = gt1_name_context_intern (psc->nc, "braceright");
-  stdenc[126] = gt1_name_context_intern (psc->nc, "asciitilde");
-  stdenc[161] = gt1_name_context_intern (psc->nc, "exclamdown");
-  stdenc[162] = gt1_name_context_intern (psc->nc, "cent");
-  stdenc[163] = gt1_name_context_intern (psc->nc, "sterling");
-  stdenc[164] = gt1_name_context_intern (psc->nc, "fraction");
-  stdenc[165] = gt1_name_context_intern (psc->nc, "yen");
-  stdenc[166] = gt1_name_context_intern (psc->nc, "florin");
-  stdenc[167] = gt1_name_context_intern (psc->nc, "section");
-  stdenc[168] = gt1_name_context_intern (psc->nc, "currency");
-  stdenc[169] = gt1_name_context_intern (psc->nc, "quotesingle");
-  stdenc[170] = gt1_name_context_intern (psc->nc, "quotedblleft");
-  stdenc[171] = gt1_name_context_intern (psc->nc, "guillemotleft");
-  stdenc[172] = gt1_name_context_intern (psc->nc, "guilsinglleft");
-  stdenc[173] = gt1_name_context_intern (psc->nc, "guilsinglright");
-  stdenc[174] = gt1_name_context_intern (psc->nc, "fi");
-  stdenc[175] = gt1_name_context_intern (psc->nc, "fl");
-  stdenc[177] = gt1_name_context_intern (psc->nc, "endash");
-  stdenc[178] = gt1_name_context_intern (psc->nc, "dagger");
-  stdenc[179] = gt1_name_context_intern (psc->nc, "daggerdbl");
-  stdenc[180] = gt1_name_context_intern (psc->nc, "periodcentered");
-  stdenc[182] = gt1_name_context_intern (psc->nc, "paragraph");
-  stdenc[183] = gt1_name_context_intern (psc->nc, "bullet");
-  stdenc[184] = gt1_name_context_intern (psc->nc, "quotesinglbase");
-  stdenc[185] = gt1_name_context_intern (psc->nc, "quotedblbase");
-  stdenc[186] = gt1_name_context_intern (psc->nc, "quotedblright");
-  stdenc[187] = gt1_name_context_intern (psc->nc, "guillemotright");
-  stdenc[188] = gt1_name_context_intern (psc->nc, "ellipsis");
-  stdenc[189] = gt1_name_context_intern (psc->nc, "perthousand");
-  stdenc[191] = gt1_name_context_intern (psc->nc, "questiondown");
-  stdenc[193] = gt1_name_context_intern (psc->nc, "grave");
-  stdenc[194] = gt1_name_context_intern (psc->nc, "acute");
-  stdenc[195] = gt1_name_context_intern (psc->nc, "circumflex");
-  stdenc[196] = gt1_name_context_intern (psc->nc, "tilde");
-  stdenc[197] = gt1_name_context_intern (psc->nc, "macron");
-  stdenc[198] = gt1_name_context_intern (psc->nc, "breve");
-  stdenc[199] = gt1_name_context_intern (psc->nc, "dotaccent");
-  stdenc[200] = gt1_name_context_intern (psc->nc, "dieresis");
-  stdenc[202] = gt1_name_context_intern (psc->nc, "ring");
-  stdenc[203] = gt1_name_context_intern (psc->nc, "cedilla");
-  stdenc[205] = gt1_name_context_intern (psc->nc, "hungarumlaut");
-  stdenc[206] = gt1_name_context_intern (psc->nc, "ogonek");
-  stdenc[207] = gt1_name_context_intern (psc->nc, "caron");
-  stdenc[208] = gt1_name_context_intern (psc->nc, "emdash");
-  stdenc[225] = gt1_name_context_intern (psc->nc, "AE");
-  stdenc[227] = gt1_name_context_intern (psc->nc, "ordfeminine");
-  stdenc[232] = gt1_name_context_intern (psc->nc, "Lslash");
-  stdenc[233] = gt1_name_context_intern (psc->nc, "Oslash");
-  stdenc[234] = gt1_name_context_intern (psc->nc, "OE");
-  stdenc[235] = gt1_name_context_intern (psc->nc, "ordmasculine");
-  stdenc[241] = gt1_name_context_intern (psc->nc, "ae");
-  stdenc[245] = gt1_name_context_intern (psc->nc, "dotlessi");
-  stdenc[248] = gt1_name_context_intern (psc->nc, "lslash");
-  stdenc[249] = gt1_name_context_intern (psc->nc, "oslash");
-  stdenc[250] = gt1_name_context_intern (psc->nc, "oe");
-  stdenc[251] = gt1_name_context_intern (psc->nc, "germandbls");
+  {
+    enc_std[i]      = gt1_name_context_intern (psc->nc, ".notdef");
+    enc_isolatin[i] = gt1_name_context_intern (psc->nc, ".notdef");
+    enc_utf8[i]     = gt1_name_context_intern (psc->nc, ".notdef");
+  };
 
-  loaded_font->encoding = stdenc;
+  for (i = 040; i <= 126; i++)
+       encode_table_1[ i] = gt1_name_context_intern (psc->nc, encode_table_1_names[i-040]);
+  for (i = 0214; i <= 0320; i++) 
+       encode_table_2[ i] = gt1_name_context_intern (psc->nc, encode_table_2_names[i-0214]);
+  for (i = 0220; i <= 0377; i++)
+       encode_table_3[ i] = gt1_name_context_intern (psc->nc, encode_table_3_names[i-0220]);
+  for (i = 0341; i <= 0373; i++)
+       encode_table_4[ i] = gt1_name_context_intern (psc->nc, encode_table_4_names[i-0341]);
 
+  for( i =  040; i <= 0176; i++)
+  {
+       enc_std[i]      = encode_table_1[i];
+       enc_isolatin[i] = encode_table_1[i];
+       enc_utf8[i]     = encode_table_1[i];
+  }
+
+  for( i = 0220; i <= 0377; i++)
+       enc_isolatin[i] = encode_table_3[i];
+  for( i = 0240; i <= 0377; i++)
+       enc_utf8[i]    = encode_table_3[i];
+  for( i = 0241; i <= 0320; i++)
+       enc_std[i]      = encode_table_2[i];
+  for( i = 0341; i <= 0373; i++)
+       enc_std[i]      = encode_table_4[i];
+  
+  loaded_font->encoding = enc_isolatin;
   loaded_font->id_charstrings = gt1_name_context_intern (psc->nc, "CharStrings");
 
   return loaded_font;
@@ -3158,6 +3184,9 @@ gt1_unload_font (Gt1LoadedFont *font)
   if (font->mfi) free_munched_font_info (font->mfi);
   if (font->fi) parseFileFree (font->fi);
 
+  glyph_outlines_destroy (font);
+  g_hash_table_destroy (font->glyph_outlines);
+
   gt1_free (font->encoding);
   gt1_free (font);
 }
@@ -3185,7 +3214,7 @@ gt1_get_glyph_outline (Gt1LoadedFont *font, int glyphnum, double *p_wx)
       print_glyph_code (glyphcode);
 #endif
       return convert_glyph_code_to_begt1_path (font->psc,
-					     glyphcode, font->fontdict, p_wx);
+					       glyphcode, font->fontdict, p_wx);
     }
   else
     return NULL;
